@@ -6,29 +6,18 @@
 #include <pygsl/rng.h>
 #include <pygsl/utils.h>
 
-/* 
- * The default macros defined by the setup script are not used when building 
- * the static library. I assume that you have numeric installed. It will not 
+/*
+ * The default macros defined by the setup script are not used when building
+ * the static library. I assume that you have numeric installed. It will not
  * work otherwise anyway.
  */
-#ifndef NUMERIC
-#define NUMERIC 1
-#else 
-#if NUMERIC <= 0
-#undef NUMERIC
-#define NUMERIC 1
-#endif
-#endif 
 
 /*
- * Numeric 21.0 does not include PyArray_UINT. Until Numerical 23.0 is 
- * more spread I will use PyArray_Long instead. The following switch allows 
+ * Numeric 21.0 does not include PyArray_UINT. Until Numerical 23.0 is
+ * more spread I will use PyArray_Long instead. The following switch allows
  * to choose one over the other.
  */
 
-#ifndef USE_PyArray_UINT
-#endif
-#if NUMERIC > 0
 #define RNG_EVALUATOR                                                        \
 {									     \
      int i;                                                                  \
@@ -55,7 +44,7 @@
      }									     \
      FUNC_MESS_END();							     \
      return (PyObject *) a_array;					     \
-}									     
+}
 /* All probability density functions return double */
 #define PDF_EVALUATOR                                                        \
 {									     \
@@ -89,60 +78,19 @@ PyGSL_BUILD_ARRAY_INFO(PyGSL_NON_CONTIGUOUS |PyGSL_INPUT_ARRAY, ARRAY_TYPE_IN, 1
      FUNC_MESS_END();                                                        \
      return (PyObject *) array_out;                                          \
 }
-#else /* Numeric */
-#define RNG_EVALUATOR                                                        \
-{									     \
-     PyObject *list;							     \
-     int i;                                                                  \
-                                                                             \
-     if(dimension <= 0){                                                     \
-	  PyErr_SetString(PyExc_ValueError,                                  \
-			  "The sample number must be positive!");            \
-	  goto fail;                                                         \
-     }                                                                       \
-     if(dimension == 1){                                                     \
-        return TOPYOBJECT(evaluator(rng->rng RNG_ARGUMENTS));                \
-     }                                                                       \
-                                                                             \
-     list = PyList_New(dimension);					     \
-     if(!list){								     \
-	  FUNC_MESS("FAIL");						     \
-	  return NULL;							     \
-     }                                                                       \
-     for (i=0; i<dimension;i++){					     \
-	  PyObject *tmp;						     \
-	  tmp = TOPYOBJECT(evaluator(rng->rng RNG_ARGUMENTS));		     \
-	  if(!tmp){							     \
-	       Py_DECREF(list);						     \
-	       return NULL;						     \
-	  }								     \
-	  PyList_SET_ITEM(list, i, tmp);				     \
-     }									     \
-     FUNC_MESS_END();                                                        \
-     return list;     							     \
-}
-#define PDF_EVALUATOR                                                        \
-{									     \
-     DATA_TYPE x; 						             \
-     int i;						                     \
-     if(!PyGSL_array_check(tmp)){	  			             \
-	  if(PyGSL_CONVERTER(tmp, &x, NULL) != GSL_SUCCESS)	             \
-	       goto fail;						     \
-	  return TOPYOBJECT(evaluator(x RNGARGUMENTS));	                     \
-     }									     \
-}									   
-#endif /* Numeric */
 
 PyObject *
 PyGSL_rng_to_double(PyGSL_rng *rng, PyObject *args, double (*evaluator)(const gsl_rng *))
 {
-     PyGSL_array_index_t dimension=1;
+     long dim = 1;
+     PyGSL_array_index_t dimension = 1;
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "|i", &dimension)){
+     if(0 == PyArg_ParseTuple(args, "|l", &dim)){
 	  return NULL;
      }
+     dimension=dim;
 
 #define RNG_ARGUMENTS
 #define DATA_TYPE     double
@@ -155,7 +103,7 @@ PyGSL_rng_to_double(PyGSL_rng *rng, PyObject *args, double (*evaluator)(const gs
      RNG_EVALUATOR
   fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      return NULL;
 }
 
@@ -179,7 +127,7 @@ PyGSL_pdf_to_double(PyObject *self, PyObject *args, double (*evaluator)(double))
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -188,22 +136,24 @@ PyGSL_pdf_to_double(PyObject *self, PyObject *args, double (*evaluator)(double))
 PyObject *
 PyGSL_rng_d_to_double(PyGSL_rng *rng, PyObject *args, double (*evaluator)(const gsl_rng *, double))
 {
-     PyGSL_array_index_t dimension=1;
+     long dim = 1;
+     PyGSL_array_index_t dimension = 1;
      double d;
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "d|i", &d, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "d|l", &d, &dim)){
 	  return NULL;
      }
+     dimension = dim;
 #undef  RNG_ARGUMENTS
-#define RNG_ARGUMENTS ,d 
+#define RNG_ARGUMENTS ,d
 
 
      RNG_EVALUATOR
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      return NULL;
 }
 
@@ -228,7 +178,7 @@ PyGSL_pdf_d_to_double(PyObject *self, PyObject *args, double (*evaluator)(double
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -237,20 +187,22 @@ PyGSL_pdf_d_to_double(PyObject *self, PyObject *args, double (*evaluator)(double
 PyObject *
 PyGSL_rng_dd_to_double(PyGSL_rng *rng, PyObject *args, double (*evaluator)(const gsl_rng *, double, double))
 {
-     PyGSL_array_index_t dimension=1;
+     long dim = 1;
+     PyGSL_array_index_t dimension = 1;
      double d1, d2;
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "dd|i", &d1, &d2, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "dd|l", &d1, &d2, &dim)){
 	  return NULL;
      }
+     dimension = dim;
 #undef  RNG_ARGUMENTS
 #define RNG_ARGUMENTS , d1, d2
 
 
      RNG_EVALUATOR
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
      return NULL;
 }
@@ -262,7 +214,7 @@ PyGSL_pdf_dd_to_double(PyObject *self, PyObject *args, double (*evaluator)(doubl
      PyObject *tmp;
      PyArrayObject *array_in = NULL, *array_out = NULL;
      double d1, d2;
-     PyGSL_array_index_t dimension=1;
+     PyGSL_array_index_t dimension = 1;
 
 
      FUNC_MESS_BEGIN();
@@ -276,7 +228,7 @@ PyGSL_pdf_dd_to_double(PyObject *self, PyObject *args, double (*evaluator)(doubl
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -285,22 +237,24 @@ PyGSL_pdf_dd_to_double(PyObject *self, PyObject *args, double (*evaluator)(doubl
 PyObject *
 PyGSL_rng_ddd_to_double(PyGSL_rng *rng, PyObject *args, double (*evaluator)(const gsl_rng *, double, double, double))
 {
-     PyGSL_array_index_t dimension=1;
+     long dim = 1;
+     PyGSL_array_index_t dimension = 1;
      double d1, d2, d3;
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "ddd|i", &d1, &d2, &d3, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "ddd|l", &d1, &d2, &d3, &dim)){
 	  return NULL;
      }
+     dimension = dim;
 #undef  RNG_ARGUMENTS
 #define RNG_ARGUMENTS , d1, d2, d3
 
 
      RNG_EVALUATOR
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      return NULL;
 }
 
@@ -327,7 +281,7 @@ PyGSL_pdf_ddd_to_double(PyObject *self, PyObject *args, double (*evaluator)(doub
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -345,14 +299,16 @@ PyGSL_rng_ui_to_double(PyGSL_rng *rng, PyObject *args, double (*evaluator)(const
 {
      PyObject *tmp, *limit_o = NULL;
      unsigned long int limit;
-     PyGSL_array_index_t dimension=1;
+     long dim = 1;
+     PyGSL_array_index_t dimension = 1;
 
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "O|i", &tmp, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "O|l", &tmp, &dim)){
 	  return NULL;
      }
+     dimension = dim;
      if(PyGSL_PYLONG_TO_ULONG(tmp, &limit, NULL) != GSL_SUCCESS)
 	  goto fail;
 #define RNG_ARGUMENTS ,limit
@@ -362,16 +318,16 @@ PyGSL_rng_ui_to_double(PyGSL_rng *rng, PyObject *args, double (*evaluator)(const
 
 
      RNG_EVALUATOR
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(limit_o);
      return NULL;
 }
 
 #undef  RNG_ARGUMENTS
 #undef  ARRAY_TYPE
-#undef  PyGSL_CONVERTER  
+#undef  PyGSL_CONVERTER
 #undef  DATA_TYPE
 #undef  ARRAY_TYPE_IN
 #undef  ARRAY_TYPE_OUT
@@ -383,7 +339,7 @@ PyGSL_pdf_ui_to_double(PyObject *self, PyObject *args, double (*evaluator)(unsig
      PyObject *tmp;
      PyArrayObject *array_in = NULL, *array_out = NULL;
      double d;
-     PyGSL_array_index_t dimension=1;
+     PyGSL_array_index_t dimension = 1;
 
 
      FUNC_MESS_BEGIN();
@@ -404,7 +360,7 @@ PyGSL_pdf_ui_to_double(PyObject *self, PyObject *args, double (*evaluator)(unsig
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -420,14 +376,16 @@ PyObject *
 PyGSL_rng_d_to_ui(PyGSL_rng *rng, PyObject *args, unsigned int  (*evaluator)(const gsl_rng *, double))
 {
      double d;
-     PyGSL_array_index_t dimension=1;
+     long dim = 1;
+     PyGSL_array_index_t dimension = 1;
 
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "d|i", &d, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "d|l", &d, &dim)){
 	  return NULL;
      }
+     dimension = dim;
 #define RNG_ARGUMENTS ,d
 #define DATA_TYPE     long
 #define ARRAY_TYPE    NPY_LONG
@@ -435,9 +393,9 @@ PyGSL_rng_d_to_ui(PyGSL_rng *rng, PyObject *args, unsigned int  (*evaluator)(con
 
 
      RNG_EVALUATOR
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      return NULL;
 }
 
@@ -456,7 +414,6 @@ PyGSL_pdf_d_to_ui(PyObject *self, PyObject *args, double (*evaluator)(unsigned i
      double d;
      PyGSL_array_index_t dimension=1;
 
-
      FUNC_MESS_BEGIN();
      assert(args && evaluator);
 
@@ -476,7 +433,7 @@ PyGSL_pdf_d_to_ui(PyObject *self, PyObject *args, double (*evaluator)(unsigned i
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -492,16 +449,18 @@ PyGSL_rng_dui_to_ui(PyGSL_rng *rng, PyObject *args, unsigned int  (*evaluator)(c
 {
      PyObject *tmp;
      double d;
-     PyGSL_array_index_t dimension=1;
+     long dim = 1;
+     PyGSL_array_index_t dimension = 1;
      unsigned long int llimit;
      unsigned int limit;
 
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "dO|i", &d, &tmp, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "dO|l", &d, &tmp, &dim)){
 	  return NULL;
      }
+     dimension = dim;
      if(PyGSL_PYLONG_TO_ULONG(tmp, &llimit, NULL) != GSL_SUCCESS)
 	  goto fail;
      limit = llimit;
@@ -513,9 +472,9 @@ PyGSL_rng_dui_to_ui(PyGSL_rng *rng, PyObject *args, unsigned int  (*evaluator)(c
 
 
      RNG_EVALUATOR
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      return NULL;
 }
 
@@ -534,7 +493,7 @@ PyGSL_pdf_dui_to_ui(PyObject *self, PyObject *args, double (*evaluator)(unsigned
      PyGSL_array_index_t dimension=1;
      unsigned int n;
      double p;
-	  
+
 
      FUNC_MESS_BEGIN();
      assert(args && evaluator);
@@ -558,7 +517,7 @@ PyGSL_pdf_dui_to_ui(PyObject *self, PyObject *args, double (*evaluator)(unsigned
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -575,15 +534,16 @@ PyGSL_rng_dd_to_ui(PyGSL_rng *rng, PyObject *args, unsigned int  (*evaluator)(co
 {
 
      double d1, d2;
-     PyGSL_array_index_t dimension=1;
-
+     PyGSL_array_index_t dimension = 1;
+     long dim = 1;
 
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "dd|i", &d1, &d2, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "dd|l", &d1, &d2, &dim)){
 	  return NULL;
      }
+     dimension = dim;
 
 #define RNG_ARGUMENTS ,d1 , d2
 #define DATA_TYPE     long
@@ -592,9 +552,9 @@ PyGSL_rng_dd_to_ui(PyGSL_rng *rng, PyObject *args, unsigned int  (*evaluator)(co
 
 
      RNG_EVALUATOR
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      return NULL;
 }
 
@@ -611,7 +571,7 @@ PyGSL_pdf_dd_to_ui(PyObject *self, PyObject *args, double (*evaluator)(const uns
      PyArrayObject *array_in = NULL, *array_out = NULL;
      PyGSL_array_index_t dimension=1;
      double d1, d2;
-	  
+
 
      FUNC_MESS_BEGIN();
      assert(args && evaluator);
@@ -631,7 +591,7 @@ PyGSL_pdf_dd_to_ui(PyObject *self, PyObject *args, double (*evaluator)(const uns
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -643,21 +603,22 @@ PyGSL_pdf_dd_to_ui(PyObject *self, PyObject *args, double (*evaluator)(const uns
 #undef  TOPYOBJECT
 
 PyObject *
-PyGSL_rng_uiuiui_to_ui(PyGSL_rng *rng, PyObject *args, 
+PyGSL_rng_uiuiui_to_ui(PyGSL_rng *rng, PyObject *args,
 		       unsigned int  (*evaluator)(const gsl_rng *, unsigned int, unsigned int, unsigned int))
 {
      PyObject *tmp1, *tmp2, *tmp3;
-     PyGSL_array_index_t dimension=1;
+     PyGSL_array_index_t dimension = 1;
+     long dim = 1;
      unsigned int u1, u2, u3;
      unsigned long int lu1, lu2, lu3;
 
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "OOO|i", &tmp1, &tmp2, &tmp3, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "OOO|l", &tmp1, &tmp2, &tmp3, &dim)){
 	  return NULL;
      }
-
+     dimension = dim;
 
      if(PyGSL_PYLONG_TO_ULONG(tmp1, &lu1, NULL) != GSL_SUCCESS) goto fail;
      if(PyGSL_PYLONG_TO_ULONG(tmp2, &lu2, NULL) != GSL_SUCCESS) goto fail;
@@ -673,9 +634,9 @@ PyGSL_rng_uiuiui_to_ui(PyGSL_rng *rng, PyObject *args,
 
 
      RNG_EVALUATOR
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      return NULL;
 }
 
@@ -685,7 +646,7 @@ PyGSL_rng_uiuiui_to_ui(PyGSL_rng *rng, PyObject *args,
 #undef  TOPYOBJECT
 
 PyObject *
-PyGSL_pdf_uiuiui_to_ui(PyObject *self, PyObject *args, 
+PyGSL_pdf_uiuiui_to_ui(PyObject *self, PyObject *args,
 		       double (*evaluator)(const unsigned int, const unsigned int, const unsigned int, unsigned int))
 {
 
@@ -693,7 +654,7 @@ PyGSL_pdf_uiuiui_to_ui(PyObject *self, PyObject *args,
      PyArrayObject *array_in = NULL, *array_out = NULL;
      PyGSL_array_index_t dimension=1;
      unsigned int u1, u2, u3;
-	  
+
 
      FUNC_MESS_BEGIN();
      assert(args && evaluator);
@@ -717,9 +678,9 @@ PyGSL_pdf_uiuiui_to_ui(PyObject *self, PyObject *args,
 #define ARRAY_TYPE_OUT   NPY_DOUBLE
      PDF_EVALUATOR
 
- fail:     
+ fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(array_in);
      Py_XDECREF(array_out);
      return NULL;
@@ -734,23 +695,25 @@ PyGSL_pdf_uiuiui_to_ui(PyObject *self, PyObject *args,
 PyObject *
 PyGSL_rng_ddd_to_dd(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_rng *, double, double, double, double *, double *))
 {
-     PyGSL_array_index_t dimension=1, dims[2], i;
+     PyGSL_array_index_t dimension = 1, dims[2], i;
+     long dim = 1;
      PyArrayObject *a_array;
      double *data, d1, d2, d3;
 
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "ddd|i", &d1, &d2, &d3, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "ddd|l", &d1, &d2, &d3, &dim)){
 	  return NULL;
      }
+     dimension = dim;
      dims[0] = dimension;
      dims[1] = 2;
-     if(dimension <= 0){                                                    
-	  PyErr_SetString(PyExc_ValueError,                                  
-			  "The sample number must be positive!");            
-	  return NULL;                                                        
-     }                                                                       
+     if(dimension <= 0){
+	  PyErr_SetString(PyExc_ValueError,
+			  "The sample number must be positive!");
+	  return NULL;
+     }
 
      if(dimension == 1){
 	  a_array = (PyArrayObject *) PyGSL_New_Array(1, &dims[1], NPY_DOUBLE);
@@ -773,7 +736,7 @@ PyGSL_rng_ddd_to_dd(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_
 }
 
 PyObject *
-PyGSL_pdf_ddd_to_dd(PyObject *self, PyObject *args, 
+PyGSL_pdf_ddd_to_dd(PyObject *self, PyObject *args,
 		    double (*evaluator)(const double, const double, const double, const double, const double))
 {
 
@@ -790,9 +753,7 @@ PyGSL_pdf_ddd_to_dd(PyObject *self, PyObject *args,
      if(0 == PyArg_ParseTuple(args, "OOddd", &tmp1, &tmp2, &d1, &d2, &d3)){
 	  return NULL;
      }
-#ifdef NUMERIC
      if((!PyGSL_array_check(tmp1)) && (!PyGSL_array_check(tmp2)))
-#endif
      {  /* No arrays, just calculate one float */
 	  if(!PyGSL_array_check(tmp1)){
 	      if(PyGSL_PYFLOAT_TO_DOUBLE(tmp1, &x, NULL) != GSL_SUCCESS){
@@ -815,13 +776,13 @@ PyGSL_pdf_ddd_to_dd(PyObject *self, PyObject *args,
 	  int i;
 	  double *data_out;
 
-	  
+
 	  array_x = PyGSL_vector_check(tmp1, -1, PyGSL_DARRAY_INPUT(1), NULL, NULL);
 	  if(array_x == NULL)
 	       goto fail;
 	  dimension = PyArray_DIM(array_x, 0);
-	  /* 
-	   * PyGSL_PyArray_PREPARE_gsl_vector_view checks if the input can be converted. 
+	  /*
+	   * PyGSL_PyArray_PREPARE_gsl_vector_view checks if the input can be converted.
 	   * Dimension -1 means no check necessary
 	   */
 	  array_y = PyGSL_vector_check(tmp2, -1, PyGSL_DARRAY_INPUT(1), NULL, NULL);
@@ -832,15 +793,15 @@ PyGSL_pdf_ddd_to_dd(PyObject *self, PyObject *args,
 	       dimension = PyArray_DIM(array_y, 0);
 	  else
 	       assert(PyArray_DIM(array_y, 0) == dimension);
-	  
+
 	  array_out = (PyArrayObject *) PyGSL_New_Array(1, &dimension, NPY_DOUBLE);
 	  if(array_out == NULL)
 	       goto fail;
 
 	  DEBUG_MESS(2, "Evaluating pdf at %p",   (void *) evaluator);
-	  DEBUG_MESS(2, "Evaluating array x at %p with data at %p and strides of %ld", (void *) array_x, 
+	  DEBUG_MESS(2, "Evaluating array x at %p with data at %p and strides of %ld", (void *) array_x,
 		     (void *) PyArray_DATA(array_x), PyArray_STRIDE(array_x, 0));
-	  for(i=0; i<dimension; i++){			
+	  for(i=0; i<dimension; i++){
 	       DEBUG_MESS(2, "Evaluating element [%d]", i);
 	       x =  *((double *)(PyArray_GETPTR1(array_x, i)));
 	       y =  *((double *)(PyArray_GETPTR1(array_y, i)));
@@ -849,7 +810,7 @@ PyGSL_pdf_ddd_to_dd(PyObject *self, PyObject *args,
 	  }
 	  DEBUG_MESS(2, "Done %ld iterations", (long)dimension);
 
-	  Py_DECREF(array_x);						       
+	  Py_DECREF(array_x);
 	  Py_DECREF(array_y);
 	  FUNC_MESS_END();
 	  return (PyObject *) array_out;
@@ -858,7 +819,7 @@ PyGSL_pdf_ddd_to_dd(PyObject *self, PyObject *args,
 
 	  fail:
 	  FUNC_MESS("Fail");
-	  PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+	  PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
 	  Py_XDECREF(array_x);
 	  Py_XDECREF(array_y);
 	  Py_XDECREF(array_out);
@@ -868,45 +829,47 @@ PyGSL_pdf_ddd_to_dd(PyObject *self, PyObject *args,
 /*
  * handles the following wrapper routines:
  *        rng_to_dd :   type value = 2
- *        rng_to_ddd :  type value = 3  
+ *        rng_to_ddd :  type value = 3
  *        rng_to_nd :   type value = 0  to be able to handle rng_to_dddd in future
  */
 PyObject*
 PyGSL_rng_to_generic_nd(PyGSL_rng *rng, PyObject *args, int type, void *evaluator)
 {
-     PyGSL_array_index_t dimension=1, dims[2], i, ds=1;
+     PyGSL_array_index_t dimension = 1, dims[2], i, ds = 1;
+     long dim = 1;
      PyArrayObject *a_array;
      double *data;
      void (*evaluator_2)(const gsl_rng *, double *, double *) = NULL;
      void (*evaluator_3)(const gsl_rng *, double *, double *, double *) = NULL;
-     void (*evaluator_0)(const gsl_rng *, size_t n, double *) = NULL;     
-     
+     void (*evaluator_0)(const gsl_rng *, size_t n, double *) = NULL;
+
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
      assert(type == 2 || type == 3 || type == 0);
 
      if(type == 0){
-	  if(0 == PyArg_ParseTuple(args, "i|i", &ds, &dimension)){
+	  if(0 == PyArg_ParseTuple(args, "l|l", &ds, &dim)){
 	       return NULL;
 	  }
      }else{
-	  if(0 == PyArg_ParseTuple(args, "|i", &dimension)){
+	  if(0 == PyArg_ParseTuple(args, "|l", &dim)){
 	       return NULL;
 	  }
      }
+     dimension = dim;
 
      if(dimension <= 0){
 	  PyErr_SetString(PyExc_ValueError,
 			  "The sample number must be positive!");
-	  return NULL;             
-     }                                                                       
+	  return NULL;
+     }
 
-     if(ds <= 0){                                                    
-	  PyErr_SetString(PyExc_ValueError,                                  
-			  "The request dimensions must be positive!");            
-	  return NULL;                                                        
-     }                                                                       
+     if(ds <= 0){
+	  PyErr_SetString(PyExc_ValueError,
+			  "The request dimensions must be positive!");
+	  return NULL;
+     }
 
      dims[0] = dimension;
 
@@ -942,7 +905,7 @@ PyGSL_rng_to_generic_nd(PyGSL_rng *rng, PyObject *args, int type, void *evaluato
      FUNC_MESS_END();
      return (PyObject *) a_array;
 }
-     
+
 
 PyObject *
 PyGSL_rng_to_dd(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_rng *, double *, double *))
@@ -967,7 +930,8 @@ PyGSL_rng_to_nd(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_rng
 PyObject *
 PyGSL_rng_dA_to_dA(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_rng *, const size_t, const double * , double *))
 {
-     PyGSL_array_index_t dimension=1, dims[2], i;
+     PyGSL_array_index_t dimension = 1, dims[2], i;
+     long dim = 1;
      PyObject *tmp;
      PyArrayObject *a_array_in =NULL, *a_array_out = NULL;
      double *data_out;
@@ -975,21 +939,22 @@ PyGSL_rng_dA_to_dA(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_r
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "O|i", &tmp, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "O|l", &tmp, &dim)){
 	  return NULL;
      }
-     
+     dimension = dim;
+
      a_array_in = PyGSL_vector_check(tmp, -1, PyGSL_DARRAY_CINPUT(1), NULL, NULL);
      if(a_array_in == NULL)
 	  goto fail;
 
      dims[0] = dimension;
      dims[1] = PyArray_DIM(a_array_in, 0);
-     if(dimension <= 0){                                                    
-	  PyErr_SetString(PyExc_ValueError,                                  
-			  "The sample number must be positive!");            
-	  goto fail;                                                        
-     }                                                                       
+     if(dimension <= 0){
+	  PyErr_SetString(PyExc_ValueError,
+			  "The sample number must be positive!");
+	  goto fail;
+     }
      if (dimension == 1){
 	  a_array_out = (PyArrayObject *) PyGSL_New_Array(1, &dims[1], NPY_DOUBLE);
      }else{
@@ -1002,7 +967,7 @@ PyGSL_rng_dA_to_dA(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_r
      for(i=0; i<dimension; i++){
 	  data_out = (double *) PyArray_GETPTR1(a_array_out,  i);
 	  evaluator(rng->rng, (size_t) dims[1], (double *) PyArray_DATA(a_array_in), data_out);
-	  
+
 	  if(PyErr_Occurred()){
 	       DEBUG_MESS(3, "Already a python error occured for dim %ld", i);
 	       goto fail;
@@ -1013,7 +978,7 @@ PyGSL_rng_dA_to_dA(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_r
      return (PyObject *) a_array_out;
 
  fail:
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      Py_XDECREF(a_array_in);
      Py_XDECREF(a_array_out);
      return NULL;
@@ -1022,17 +987,17 @@ PyGSL_rng_dA_to_dA(PyGSL_rng *rng, PyObject *args, void (*evaluator)(const gsl_r
 
 
 PyObject *
-PyGSL_rng_uidA_to_uiA(PyGSL_rng *rng, PyObject *args, 
-		    void (*evaluator)(const gsl_rng *, const size_t, const unsigned int, 
+PyGSL_rng_uidA_to_uiA(PyGSL_rng *rng, PyObject *args,
+		    void (*evaluator)(const gsl_rng *, const size_t, const unsigned int,
 				      const double * , unsigned int *))
 {
-     PyGSL_array_index_t dimension=0, dimension_check=-1, dimension_tmp, dims[2], 
+     PyGSL_array_index_t dimension=0, dimension_check=-1, dimension_tmp, dims[2],
 	     i,  stride2, stride_n, stride_phi;
      PyGSL_array_info_t a_info;
      PyObject *tmp_n, *tmp_phi, *dimension_o = NULL;
      PyArrayObject *a_phi = NULL, *a_n =NULL, *a_array_out = NULL;
      double * pd_phi;
-     int use_array_dimension = 0, iterate_over_parameters = 0, line_no = __LINE__;
+     int line_no = __LINE__;
      unsigned int *data_out = NULL;
      unsigned int  *pui_n = NULL;
 
@@ -1042,18 +1007,18 @@ PyGSL_rng_uidA_to_uiA(PyGSL_rng *rng, PyObject *args,
      if(0 == PyArg_ParseTuple(args, "OO|O", &tmp_n, &tmp_phi, &dimension_o)){
 	  return NULL;
      }
-     
+
      /* default: internal sampling rate not checked */
      dimension = 0;
      /* default: any array size allowed */
      dimension_check = -1;
      /* default: single values for the parameters */
-     stride_n = 0; 
+     stride_n = 0;
      stride_phi = 0;
 
 
-     
-     a_info = PyGSL_BUILD_ARRAY_INFO(PyGSL_CONTIGUOUS | PyGSL_INPUT_ARRAY, 
+
+     a_info = PyGSL_BUILD_ARRAY_INFO(PyGSL_CONTIGUOUS | PyGSL_INPUT_ARRAY,
 				     NPY_UINT, sizeof(unsigned int), 1);
      a_n = PyGSL_vector_check(tmp_n, dimension_check, a_info, &stride_n, NULL);
      if(a_n == NULL){
@@ -1091,7 +1056,7 @@ PyGSL_rng_uidA_to_uiA(PyGSL_rng *rng, PyObject *args,
 
      DEBUG_MESS(2, "Input data: pui_N: len(%ld) stride = %ld, "
 		"pd_phishape = (%ld,%ld), stride = %ld",
-		(long) PyArray_DIM(a_n, 0), (long) stride_n, 
+		(long) PyArray_DIM(a_n, 0), (long) stride_n,
 		(long) PyArray_DIM(a_phi, 0), (long) PyArray_DIM(a_phi, 1),
 		(long) stride_phi);
 
@@ -1109,21 +1074,21 @@ PyGSL_rng_uidA_to_uiA(PyGSL_rng *rng, PyObject *args,
 				 __FILE__, __LINE__, GSL_ESANITY);
 		     line_no = __LINE__ - 3;
 		     goto fail;
-		     
+
 	     }
 	     dimension = ultmp;
 	     if(dimension_check != 1 && dimension != dimension_check){
-		     DEBUG_MESS(2, "optional sample argument was %lu array n = %ld array phi = %ld ", 
+		     DEBUG_MESS(2, "optional sample argument was %lu array n = %ld array phi = %ld ",
 				ultmp, (long) PyArray_DIM(a_n, 0), (long) PyArray_DIM(a_phi, 0));
-		     pygsl_error("at least one of the arrays gave the number" 
+		     pygsl_error("at least one of the arrays gave the number"
 				 " of samples != 1 not matching the optional argument number of samples",
 				 __FILE__, __LINE__, GSL_ESANITY);
 		     line_no = __LINE__ - 3;
-		     goto fail;		     
+		     goto fail;
 	     }
      }
 
-     
+
      /* clear up */
      if (dimension == 0){
 	     /* no dimension found up to now ... */
@@ -1141,12 +1106,12 @@ PyGSL_rng_uidA_to_uiA(PyGSL_rng *rng, PyObject *args,
 
      dims[0] = dimension;
      dims[1] = PyArray_DIM(a_phi, 1);
-     if(dimension <= 0){                                                    
-	  PyErr_SetString(PyExc_ValueError,                                  
-			  "The sample number must be positive!");            
+     if(dimension <= 0){
+	  PyErr_SetString(PyExc_ValueError,
+			  "The sample number must be positive!");
 	  line_no = __LINE__ - 3;
-	  goto fail;                                                        
-     }                                                                       
+	  goto fail;
+     }
 
      a_array_out = (PyArrayObject *) PyGSL_New_Array(2, dims, NPY_UINT);
      if(a_array_out == NULL){
@@ -1154,12 +1119,12 @@ PyGSL_rng_uidA_to_uiA(PyGSL_rng *rng, PyObject *args,
 	  goto fail;
      }
 
-     
+
      pd_phi = (double *) PyArray_DATA(a_phi);
      pui_n  = (unsigned int *) PyArray_DATA(a_n);
 
      for(i=0; i<dimension; i++){
-	     data_out = (unsigned int *) PyArray_GETPTR1(a_array_out, i);	  
+	     data_out = (unsigned int *) PyArray_GETPTR1(a_array_out, i);
 	     evaluator(rng->rng, (size_t) dims[1], pui_n[stride_n * i], &(pd_phi[stride_phi * i]), data_out);
      }
      Py_DECREF(a_phi);
@@ -1169,7 +1134,7 @@ PyGSL_rng_uidA_to_uiA(PyGSL_rng *rng, PyObject *args,
 
  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, line_no);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, line_no);
      Py_XDECREF(a_n);
      Py_XDECREF(a_phi);
      Py_XDECREF(a_array_out);
@@ -1184,7 +1149,7 @@ PyGSL_pdf_dA_to_uint_or_dA(PyObject *self, PyObject *args, void * evaluator, enu
      PyGSL_array_index_t dimension=1, k, i, line=-1;
      PyGSL_array_info_t ainfo;
 
-     double *data_p, *data_out, *data_theta, tmp_data; 
+     double *data_p, *data_out, *data_theta, tmp_data;
      unsigned int *data_n;
 
      double (*evaluator_double) (const size_t, const double [], const double []) = NULL;
@@ -1201,7 +1166,7 @@ PyGSL_pdf_dA_to_uint_or_dA(PyObject *self, PyObject *args, void * evaluator, enu
      array_p = PyGSL_vector_check(tmp, -1, PyGSL_DARRAY_INPUT(1), NULL, NULL);
      if(array_p == NULL){
 	  line = __LINE__ - 2;
-	  goto fail;	  
+	  goto fail;
      }
      k = PyArray_DIM(array_p, 0);
      DEBUG_MESS(4, "Building Matrix. Input Object @ %p with refcount %ld!", (void *) tmp1, tmp1->ob_refcnt);
@@ -1227,21 +1192,21 @@ PyGSL_pdf_dA_to_uint_or_dA(PyObject *self, PyObject *args, void * evaluator, enu
      FUNC_MESS("SWITCHING callback");
      assert(type_3darg == NPY_DOUBLE || type_3darg == NPY_LONG);
      switch(type_3darg){
-     case NPY_DOUBLE:      
+     case NPY_DOUBLE:
 	  evaluator_double = (double (*) (const size_t, const double [], const double [])) evaluator;
 	  break;
-     case NPY_LONG:      
+     case NPY_LONG:
 	  evaluator_uint    = (double (*) (const size_t, const double [], const unsigned int [])) evaluator;
 	  break;
      default:
 	  assert(0);
      }
      DEBUG_MESS(5, "array_n has %d dimensions. dim = [%ld, %ld] strides = [%ld,%ld]",
-		PyArray_NDIM(array_n), 
+		PyArray_NDIM(array_n),
 		PyArray_DIM(array_n, 0), PyArray_DIM(array_n, 1),
 		PyArray_STRIDE(array_n, 0), PyArray_STRIDE(array_n, 1));
-     DEBUG_MESS(5, "array_out has %d dimensions. dim = [%ld]" 
-		" strides = [%ld,], dimension = %ld, k = %ld", PyArray_NDIM(array_out), 
+     DEBUG_MESS(5, "array_out has %d dimensions. dim = [%ld]"
+		" strides = [%ld,], dimension = %ld, k = %ld", PyArray_NDIM(array_out),
 		(long)PyArray_DIM(array_out, 0), (long)PyArray_STRIDE(array_out, 0), (long)dimension,(long) k);
      FUNC_MESS("Evaluating callback");
      assert(PyArray_DIM(array_out, 0) >= dimension);
@@ -1261,14 +1226,14 @@ PyGSL_pdf_dA_to_uint_or_dA(PyObject *self, PyObject *args, void * evaluator, enu
 	       data_out[i] = evaluator_uint((size_t) k, data_p, data_n);
 	  }else {
 	      /*
-	       * Why did I end here?? I checked in the beginnig that it was 
-	       *  either or ... 
+	       * Why did I end here?? I checked in the beginnig that it was
+	       *  either or ...
 	       */
 	       assert(0);
 	  }
      }
 
-     DEBUG_MESS(4, "Dereferencing p @ %p  and n @ %p", 
+     DEBUG_MESS(4, "Dereferencing p @ %p  and n @ %p",
 		(void *) array_p, (void *) array_n);
      Py_DECREF(array_p);
      Py_DECREF(array_n);
@@ -1279,11 +1244,11 @@ PyGSL_pdf_dA_to_uint_or_dA(PyObject *self, PyObject *args, void * evaluator, enu
      Py_XDECREF(array_p);
      Py_XDECREF(array_n);
      Py_XDECREF(array_out);
-     return NULL;     
+     return NULL;
 }
 
 PyObject*
-PyGSL_pdf_dA_to_dA(PyObject *self, PyObject *args, 
+PyGSL_pdf_dA_to_dA(PyObject *self, PyObject *args,
 		   double (*evaluator) (const size_t, const double [], const double []))
 {
 
@@ -1295,7 +1260,7 @@ PyGSL_pdf_dA_to_dA(PyObject *self, PyObject *args,
 }
 
 PyObject*
-PyGSL_pdf_uidA_to_uiA(PyObject *self, PyObject *args, 
+PyGSL_pdf_uidA_to_uiA(PyObject *self, PyObject *args,
 		      double (*evaluator) (const size_t, const double [], const unsigned int []))
 {
      PyObject *r;
@@ -1305,26 +1270,23 @@ PyGSL_pdf_uidA_to_uiA(PyObject *self, PyObject *args,
 }
 
 
-#ifdef NUMERIC
-#undef NUMERIC
-#define NUMERIC 0
-#endif
 
-/* 
- * Now the unsigned long stuff follows. Numeric arrays do not support unsigned long int. 
- * So I switch to lists here ! 
+/*
+ * Now the unsigned long stuff follows. Numeric arrays do not support unsigned long int.
+ * So I switch to lists here !
  */
 PyObject *
 PyGSL_rng_to_ulong(PyGSL_rng *rng, PyObject *args, unsigned long int (*evaluator)(const gsl_rng *))
 {
-     PyGSL_array_index_t dimension=1;
-
+     PyGSL_array_index_t dimension = 1;
+     long dim = 1;
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "|i", &dimension)){
+     if(0 == PyArg_ParseTuple(args, "|l", &dim)){
 	  return NULL;
      }
+     dimension = dim;
 
 #define RNG_ARGUMENTS
 #define DATA_TYPE     unsigned long int
@@ -1334,10 +1296,10 @@ PyGSL_rng_to_ulong(PyGSL_rng *rng, PyObject *args, unsigned long int (*evaluator
 
      RNG_EVALUATOR
 
- fail:  
+ fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
-     return NULL;	  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
+     return NULL;
 }
 #undef  RNG_ARGUMENTS
 #undef  DATA_TYPE
@@ -1347,17 +1309,19 @@ PyGSL_rng_to_ulong(PyGSL_rng *rng, PyObject *args, unsigned long int (*evaluator
 PyObject *
 PyGSL_rng_ul_to_ulong(PyGSL_rng *rng, PyObject *args, unsigned long int (*evaluator)(const gsl_rng *, unsigned long int))
 {
-     PyGSL_array_index_t dimension=1;
-
+     PyGSL_array_index_t dimension = 1;
+     long dim = 1;
      PyObject *tmp;
      unsigned long int limit;
 
      FUNC_MESS_BEGIN();
      assert(rng && args && evaluator);
 
-     if(0 == PyArg_ParseTuple(args, "O|i", &tmp, &dimension)){
+     if(0 == PyArg_ParseTuple(args, "O|l", &tmp, &dim)){
 	  return NULL;
      }
+     dimension = dim;
+
      if(PyGSL_PYLONG_TO_ULONG(tmp, &limit, NULL) != GSL_SUCCESS) goto fail;
 
 #define RNG_ARGUMENTS ,limit
@@ -1367,8 +1331,8 @@ PyGSL_rng_ul_to_ulong(PyGSL_rng *rng, PyObject *args, unsigned long int (*evalua
 
      RNG_EVALUATOR
 
-  fail:  
+  fail:
      FUNC_MESS("FAIL");
-     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);  
+     PyGSL_add_traceback(module, __FILE__, __FUNCTION__, __LINE__);
      return NULL;
 }
